'********************************************************************
'*
'* File				:        IE-GetSettings.vbs
'* Date of creation :        18-iv-2004
'* Last modification:        06-vi-2011
'* Version			:        1.2
'* Author			:        R.Danard
'*
'* Main Function :
'*  dump the Internet Explorer settings from the registry
'*
'* Syntax 	 : cscript IE-GetSettings.vbs > dump_%computername%_%username%.txt
'*
'* 1.0: original version
'* 1.1: added entries for new Security Zones settings
'* 1.2: GPO applied settings taken into account
'********************************************************************

'--------------------------------------------------------------------
' retrieval of Internet Options
'--------------------------------------------------------------------

Option Explicit

'--------------------------------------------------------------------
' Registry
const HKEY_CURRENT_USER  = &H80000001
const HKEY_LOCAL_MACHINE = &H80000002
const HKEY_USERs         = &H80000003

const REG_SZ        = 1
const REG_EXPAND_SZ = 2
const REG_BINARY    = 3
const REG_DWORD     = 4
const REG_MULTI_SZ  = 7

Const VALUE_NOT_FOUND = "[not found]"

'--------------------------------------------------------------------

Const MY_COMPUTER_ZONE = 0
Const INTERNET_ZONE    = 3
Const INTRANET_ZONE    = 1
Const RESTRICTED_SITES = 4
Const TRUSTED_SITES    = 2

'--------------------------------------------------------------------
' file management

Const OpenAsASCII   = 0
Const OpenAsUnicode	= -1

' FileSystemObject.CreateTextFile
Const OverwriteIfExist 	= -1
Const FailIfExist      	= 0

 ' FileSystemObject.OpenTextFile
Const OpenAsDefault    	= -2
Const CreateIfNotExist 	= -1
Const FailIfNotExist   	= 0
Const ForReading   		= 1
Const ForWriting   		= 2
Const ForAppending 		= 8

'--------------------------------------------------------------------

Const LOG_TO_SCREEN = 1
Const LOG_TO_FILE 	= 2

'--------------------------------------------------------------------

Dim sLocalComputer
Dim sLocalUser
Dim g_oReg
Dim hHive
Dim sLogFile
Dim g_oFSO
Dim g_oLogFile
Dim iLogTo
Dim sLogFileName
Dim g_oShell

iLogTo = LOG_TO_FILE 
	
Call Init()

'On Error Resume Next

WriteLog "===================================================================="
WriteLog "Internet options "
WriteLog "dump for computer '" & sLocalComputer & "' and user '" & sLocalUser & "'"
WriteLog "===================================================================="
WriteLog ""
WriteLog "===================================================================="
WriteLog "Internet options - General"
WriteLog "===================================================================="

'--------------------------------------------------------------------
' "General" tab
'--------------------------------------------------------------------

Call DisplayGeneralSettings(sLocalComputer)

WriteLog "> Connections (HKCU)"
	
Call DisplayConnectionsSettings(sLocalComputer, HKEY_CURRENT_USER, "")

WriteLog "> Programs (HKCU)"
	
Call DisplayProgramsSettings(sLocalComputer, HKEY_CURRENT_USER, "")

WriteLog "> Programs (HKLM)"
	
Call DisplayProgramsSettings(sLocalComputer, HKEY_LOCAL_MACHINE, "")

'WriteLog "> Programs (HKU\.DEFAULT)"

'Call DisplayProgramsSettings(sComputer, HKEY_USERS, ".DEFAULT\")

WriteLog ""
WriteLog "===================================================================="
WriteLog "Internet options - Advanced Settings"
WriteLog "===================================================================="

Call DisplayAdvancedSettings (sLocalComputer)

'--------------------------------------------------------------------
' "Security" tab - HKCU
'--------------------------------------------------------------------

WriteLog ""
WriteLog "===================================================================="
WriteLog "Internet options - Security (HKCU)"
WriteLog "===================================================================="

Call DisplaySecurity(sLocalComputer,HKEY_CURRENT_USER,"")

'--------------------------------------------------------------------
' "Security" - HKLM
'--------------------------------------------------------------------

WriteLog ""
WriteLog "===================================================================="
WriteLog "Internet options - Security (HKLM)"
WriteLog "===================================================================="

Call DisplaySecurity(sLocalComputer,HKEY_LOCAL_MACHINE,"")

'--------------------------------------------------------------------
' "Security" - HKU\.Default
'--------------------------------------------------------------------

'WriteLog "===================================================================="
'WriteLog "Internet options - Security (HKU\.Default)"
'WriteLog "===================================================================="

'Call DisplaySecurity(sLocalComputer,HKEY_USERS,".DEFAULT\")

MsgBox "Done"

WScript.Quit 

'--------------------------------------------------------------------
' Initialize the global variables
'--------------------------------------------------------------------

Sub Init()

	Set g_oShell = WScript.CreateObject("WScript.Shell")

	sLocalComputer = g_oShell.ExpandEnvironmentStrings("%ComputerName%")
	sLocalUser = g_oShell.ExpandEnvironmentStrings("%UserName%")
	
	Set g_oFSO = CreateObject("Scripting.FileSystemObject")
	Set g_oReg = GetObject("winmgmts:{impersonationLevel=impersonate}!\\" & sLocalComputer & "\root\default:StdRegProv")
	
	sLogFileName = g_oShell.ExpandEnvironmentStrings("%Temp%\InternetSettings_" & sLocalComputer & "_" & sLocalUser & ".log")
	
	Call InitLog(sLogFileName)

End Sub

'--------------------------------------------------------------------
' Initialize the log file
'--------------------------------------------------------------------

Sub InitLog (sFileName)

	If iLogTo = LOG_TO_SCREEN  Then
		Exit Sub
	End If
	WScript.Echo sfilename
	
	Set g_oLogFile = g_oFSO.CreateTextFile(sFileName)
	g_oLogFile.Close 

	MsgBox "Log file= " & sFileName,vbOKOnly 
	
	
End Sub

'--------------------------------------------------------------------
' write the results to the log, either on screen or in a file
'--------------------------------------------------------------------

Sub WriteLog (sMessage)

	If iLogTo = LOG_TO_SCREEN Then
		WScript.Echo sMessage
	Else
		Set g_oLogFile = g_oFSO.OpenTextFile (sLogFileName,forappending)
		g_oLogFile.WriteLine sMessage 
		g_oLogFile.Close 
	End If
	
End Sub

'--------------------------------------------------------------------
' content of the "General" tab
'--------------------------------------------------------------------

Sub DisplayGeneralSettings(sComputer)

	Dim sKeyPath
	Dim sValueName
	Dim sValue
	Dim dwValue
	Dim binValue

	WriteLog "> General - Home page"
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Main"
	sValueName = "Start Page"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Home page URL: " & sValue
	
	' Temporary Internet Files settings
	
	WriteLog "> General - Temporary Internet Files settings"
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Windows\CurrentVersion\Explorer\User Shell Folders"
	sValueName = "Cache"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Temporary Internet Files folder: " & sValue
	
	hHive = HKEY_LOCAL_MACHINE
	sKeyPath = "Software\Microsoft\Internet Explorer\Main"
	sValueName = "Cache_percent_of_disk"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	sValue = Mid(sValue,1,2)
	
	WriteLog " (HKLM) Cache percent of disk: " & HexToInt(sValue)
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Windows\CurrentVersion\Internet Settings\5.0\Cache\Content"
	sValueName = "CacheLimit"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Cache limit: " & sValue & " bytes"
	
	' History
	
	WriteLog "> General - History"
	
	hHive = HKEY_LOCAL_MACHINE
	sKeyPath = "Software\Microsoft\Windows\CurrentVersion\Internet Settings\Url History"
	sValueName = "DaysToKeep"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	sValue = Mid(sValue,1,2)
	
	WriteLog " (HKLM) Days to keep pages in history: " & HexToInt(sValue)
	
	' Colors
	
	WriteLog "> General - Colors"
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Main"
	sValueName = "Use_DlgBox_Colors"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Use Windows colors: " & sValue
	
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Text Color"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Text color: " & sValue
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Background Color"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Background color: " & sValue
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Anchor Color"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Anchor color: " & sValue
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Anchor Color Hover"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Anchor color hover: " & sValue
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Anchor Color Visited"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Anchor color visited: " & sValue
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Use Anchor Hover Color"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) Use Anchor hover color: " & sValue
	
	' Fonts
	
	WriteLog "> General - Fonts"
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\International\Scripts"
	sValueName = "Default_Script"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	WriteLog " (HKCU) Default script: " & sValue
	
	Dim sDefaultScript
	
	If sValue <> VALUE_NOT_FOUND Then
	
		sDefaultScript = sValue		
		
		hHive = HKEY_CURRENT_USER
		sKeyPath = "Software\Microsoft\Internet Explorer\International\Scripts\" & HexToInt(sDefaultScript)
		sValueName = "IEPropFontName"
		sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)		
		WriteLog " (HKCU) Web page font: " & sValue
		
		hHive = HKEY_CURRENT_USER
		sKeyPath = "Software\Microsoft\Internet Explorer\International\Scripts\"& HexToInt(sDefaultScript)
		sValueName = "IEFixedFontName"
		sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
		
		WriteLog " (HKCU) Plain text font: " & sValue
		
	End If 	
	' Languages
	
	WriteLog "> General - Languages"
	
	' - default language
	
	' - available languages
	
	' Accessibility
	
	WriteLog "> General - Accessibilitty"
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Always Use My Colors"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)

	If sValue <> VALUE_NOT_FOUND Then
		sValue = (sValue = 1)
	End If
	
	WriteLog " (HKCU) ignore colors specified on web pages: " & sValue
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Always Use My Font Face"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	If sValue <> VALUE_NOT_FOUND Then
		sValue = (sValue = 1)
	End If
	
	WriteLog " (HKCU) ignore font styles specified on web pages: " & sValue 
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Settings"
	sValueName = "Always Use My Font Size"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)

	If sValue <> VALUE_NOT_FOUND Then
		sValue = (sValue = 1)
	End If
		
	WriteLog " (HKCU) ignore font sizes specified on web pages: " & sValue
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Styles"
	sValueName = "Use My Stylesheet"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)

	If sValue <> VALUE_NOT_FOUND Then
		sValue = (sValue = 1)
	End If
		
	WriteLog " (HKCU) Format documents using my style sheet: " & sValue
	
	hHive = HKEY_CURRENT_USER
	sKeyPath = "Software\Microsoft\Internet Explorer\Styles"
	sValueName = "User Stylesheet"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog " (HKCU) my style sheet: " & sValue

End Sub 

'--------------------------------------------------------------------
' content of the "Privacy" tab
'--------------------------------------------------------------------

Sub DisplayPrivacySettings(sComputer)

	Dim sKeyPath
	Dim sValueName
	Dim sValue
	Dim dwValue
	Dim binValue

	WriteLog "> Privacy"
	
End Sub

'--------------------------------------------------------------------
' content of the "Connections" tab
'--------------------------------------------------------------------

Sub DisplayConnectionsSettings(sComputer, hHive, sSubKey)

	Dim sKeyPath
	Dim sValueName
	Dim sValue
	Dim sSubstring
	Dim iValue
	
	WriteLog "> Connections - LAN Settings"
	
	sKeyPath = sSubKey & "Software\Microsoft\Windows\CurrentVersion\Internet Settings\Connections"
	sValueName = "DefaultConnectionSettings"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	sSubstring = Mid(sValue,18,1)
	iValue = HexToInt(sSubstring)
	
	WriteLog "  Automatically detect settings: " & ((iValue And 8) = 8)
	
	WriteLog "  Use automatic configuration script: " & ((iValue And 4) = 4)
	
	sKeyPath = sSubKey & "Software\Microsoft\Windows\CurrentVersion\Internet Settings"
	sValueName = "AutoConfigURL"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Automatic configuration script: " & sValue

	sKeyPath = sSubKey & "Software\Microsoft\Windows\CurrentVersion\Internet Settings"
	sValueName = "ProxyEnable"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Use proxy server: " & (sValue = 1)
	
	sKeyPath = sSubKey & "Software\Microsoft\Windows\CurrentVersion\Internet Settings"
	sValueName = "ProxyServer"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Proxy server address & port: " & sValue
	
	sKeyPath = sSubKey & "Software\Microsoft\Windows\CurrentVersion\Internet Settings"
	sValueName = "ProxyOverride"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Bypass proxy server for local addresses: " & sValue
		
End Sub 

'--------------------------------------------------------------------
' content of the "Programs" tab
'--------------------------------------------------------------------

Sub DisplayProgramsSettings(sComputer, hHive, sSubKey)

	Dim sKeyPath
	Dim sValueName
	Dim sValue
	
	sKeyPath = sSubKey & "Software\Microsoft\Internet Explorer\Default HTML Editor"
	sValueName = "Description"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  HTML Editor: " & sValue
	
	sKeyPath = sSubKey & "Software\Clients\Mail"
	sValueName = ""
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  E-mail: " & sValue
	
	sKeyPath = sSubKey & "Software\Clients\News"
	sValueName = ""
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Newsgroup: " & sValue
	
	sKeyPath = sSubKey & "Software\Clients\Internet Call"
	sValueName = ""
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Internet call: " & sValue
	
	sKeyPath = "Software\Clients\Calendar"
	sValueName = ""
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Calendar: " & sValue
	
	sKeyPath = sSubKey & "Software\Clients\Contacts"
	sValueName = ""
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Contact list: " & sValue
	
	sKeyPath = sSubKey & "Software\Microsoft\Internet Explorer\Main"
	sValueName = "Check_Associations"
	sValue =  Registry_ReadKey(sComputer, hHive,sKeyPath,sValueName)
	
	WriteLog "  Check that Internet Explorer is the default browser: " & sValue

End Sub

'--------------------------------------------------------------------
' content of the "Advanced" tab
'--------------------------------------------------------------------

Sub DisplayAdvancedSettings(sComputer)

	Dim sKeyPath
	
	sKeyPath = "SOFTWARE\Microsoft\Internet Explorer\AdvancedOptions"

	Call DisplaySettingsDetails(sComputer,sKeyPath,0,"")
	
End Sub

'--------------------------------------------------------------------
' get the security settings for a registry hive
'--------------------------------------------------------------------

Sub DisplaySecurity (sComputer,hRootKey,sSubKey)

	WriteLog "--------------------------------------------------------------------"
	WriteLog " My Computer"
	WriteLog "--------------------------------------------------------------------"
	
	Call DisplaySecuritySettings(sComputer,MY_COMPUTER_ZONE, hRootKey,sSubKey)
	
	WriteLog "--------------------------------------------------------------------"
	WriteLog " Internet Zone"
	WriteLog "--------------------------------------------------------------------"
	
	Call DisplaySecuritySettings(sComputer,INTERNET_ZONE, hRootKey,sSubKey)
	
	WriteLog "--------------------------------------------------------------------"
	WriteLog " Local Intranet Zone"
	WriteLog "--------------------------------------------------------------------"
	
	Call DisplaySecuritySettings(sComputer,INTRANET_ZONE, hRootKey,sSubKey)
	
	WriteLog "--------------------------------------------------------------------"
	WriteLog " Restricted Sites Zone"
	WriteLog "--------------------------------------------------------------------"
	
	Call DisplaySecuritySettings(sComputer,RESTRICTED_SITES, hRootKey,sSubKey)
	
	WriteLog "--------------------------------------------------------------------"
	WriteLog " Trusted Sites Zone"
	WriteLog "--------------------------------------------------------------------"
	
	Call DisplaySecuritySettings(sComputer,TRUSTED_SITES, hRootKey,sSubKey)

End Sub

'--------------------------------------------------------------------
' get the security settings for a zone
'--------------------------------------------------------------------

Sub DisplaySecuritySettings (sComputer, intZone, hHive, strRegistrySection)

	Dim sKeyPath
	Dim aRegKeys
	Dim aRegValues
	Dim aRegTypes
	
	' list the sites defined in the zone
	
	sKeyPath = "SOFTWARE\Microsoft\Windows\CurrentVersion\Internet Settings\ZoneMap\Domains"	
	
	If Registry_EnumKeys(sComputer,hHive,sKeyPath,aRegKeys) Then
		WriteLog "> Sites defined in this zone:"		
		Call DisplayZoneMap(sComputer,hHive,sKeyPath,aRegKeys,intZone)
	Else 
		WriteLog "> no sites defined in this zone"	
		WriteLog ""
	End If 	
	
	sKeyPath = "SOFTWARE\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\ZoneMapKey"
	
	If Registry_EnumValues(sComputer,hHive,sKeyPath,aRegValues,aRegTypes) Then
		WriteLog "> Sites defined in this zone by policies:"		
		Call DisplayZoneMapPolicies(sComputer,hHive,sKeyPath,aRegValues,aRegTypes,intZone)
	Else 
		WriteLog "> no sites defined in this zone by policies"	
		WriteLog ""
	End If 
	
	sKeyPath = "SOFTWARE\Microsoft\Windows\CurrentVersion\Internet Settings\SO"
	
	Call DisplaySettingsDetails(sComputer,sKeyPath,intZone,"")
		
End Sub

Sub DisplaySettingsDetails(sComputer,sKeyPath,intZone,strIndentation)

	Dim aRegKeys
	Dim sRegKey
	Dim sValueName
	Dim sDisplayText
	Dim sValueType
	Dim sValue
	Dim sRegKeyPath
	Dim sDisplayKeyPath
	Dim sDisplayValueName
	Dim sValueChecked
	Dim sValueMask
	
	' get the list of subkeys	
	If not Registry_EnumKeys(sComputer,HKEY_LOCAL_MACHINE,sKeyPath,aRegKeys) Then
		Exit Sub
	End If 

	For Each sRegKey In aRegKeys
	' get the heading information for the key
		sValueName = "Text"
		sRegKeyPath = sKeyPath & "\" & sRegKey
		sDisplayText = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)	
		If sDisplayText = VALUE_NOT_FOUND Then
			sDisplayText = sRegKey 
		End If 
		sValueName = "Type"
		sValueType = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)	
		Select Case LCase(sValueType)
			Case "group"
				WriteLog strIndentation & "> " & sDisplayText				
				' recurse on the new key
				Call DisplaySettingsDetails(sComputer,sRegKeyPath,intZone,strIndentation & " ")
			Case Else
				' 1 - values not defined by policies
				' registry path To the actual data
				sValueName = "RegPath"
				sDisplayKeyPath = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)
				' registry value to read
				sValueName = "ValueName"
				sDisplayValueName = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)
				' values for checked (radio and checkbox) and unchecked (checkbox)
				sValueName = "CheckedValue"
				sValueChecked = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)
				' mask to check the value against
				sValueName = "Mask"
				sValueMask = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)
				' get the information to display
				' replace %s by the zone number
				sDisplayKeyPath = Replace(sDisplayKeyPath,"%s",intZone)
				sValue = Registry_ReadKey(sComputer,hHive,sDisplayKeyPath,sDisplayValueName)
				If sValue <> VALUE_NOT_FOUND and sValueMask <> VALUE_NOT_FOUND Then
					sValue = sValue And sValueMask
					sValue = CInt(sValue)
					sValueChecked = CInt(sValueChecked)
				End If 
				Select Case lcase(sValueType)
					Case VALUE_NOT_FOUND
						WriteLog strIndentation & "> " & sDisplayText
					Case "checkbox", "radio"
						WriteLog strIndentation & "* " & sDisplayText & ": " & (sValue = sValueChecked) & " (" & sValue & ")"
					Case Else
						WriteLog strIndentation & sDisplayText & ": " & sValue
				End Select 
				' 2 - values defined by policies
				' registry path to the actual data
				sValueName = "RegPoliciesPath"
				sDisplayKeyPath = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)
				' registry value to read
				sValueName = "ValueName"
				sDisplayValueName = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)
				' values for checked (radio and checkbox) and unchecked (checkbox)
				sValueName = "CheckedValue"
				sValueChecked = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)
				' mask to check the value against
				sValueName = "Mask"
				sValueMask = Registry_ReadKey(sComputer, HKEY_LOCAL_MACHINE,sRegKeyPath,sValueName)
				' get the information to display
				' replace %s by the zone number
				sDisplayKeyPath = Replace(sDisplayKeyPath,"%s",intZone)
				sValue = Registry_ReadKey(sComputer,hHive,sDisplayKeyPath,sDisplayValueName)
				' display the result for policies only if something is set
				If sValue <> VALUE_NOT_FOUND and sValueMask <> VALUE_NOT_FOUND Then
					sValue = sValue And sValueMask
					sValue = CInt(sValue)
					sValueChecked = CInt(sValueChecked)
					Select Case lcase(sValueType)
						Case VALUE_NOT_FOUND
							WriteLog strIndentation & "> " & sDisplayText
						Case "checkbox", "radio"
							WriteLog strIndentation & "* Policy " & sDisplayText & ": " & (sValue = sValueChecked) & " (" & sValue & ")"
						Case Else
							WriteLog strIndentation & "Policy " & sDisplayText & ": " & sValue
					End Select 
				End If 
		End Select 			
	Next 
	
End Sub


Sub DisplayZoneMap(sComputer,hHive,sKeyPath,aRegKeys,intZone)

	Dim sRegKey
	Dim sValueName
	Dim sRegKeyPath
	Dim dwValue
	
	For Each sRegKey In aRegKeys
	wscript.echo sKeyPath & "\" & sRegKey
		sValueName = "http"
		sRegKeyPath = sKeyPath & "\" & sRegKey 
		dwValue = Registry_ReadKey(sComputer,hHive,sRegKeyPath,sValueName)
		If dwValue <> VALUE_NOT_FOUND Then
			dwValue = CInt(dwValue)
			If dwValue = intZone Then
				WriteLog " " & sValueName & "://" & sRegKey 
			End If 
		End If 
		sValueName = "https"
		sRegKeyPath = sKeyPath & "\" & sRegKey 
		dwValue = Registry_ReadKey(sComputer,hHive,sRegKeyPath,sValueName)
		If dwValue <> VALUE_NOT_FOUND Then
			dwValue = CInt(dwValue)
			If dwValue = intZone Then
				WriteLog " " & sValueName & "://" & sRegKey 
			End If 
		End If 
		sValueName = "*"
		sRegKeyPath = sKeyPath & "\" & sRegKey 
		dwValue = Registry_ReadKey(sComputer,hHive,sRegKeyPath,sValueName)
		If dwValue <> VALUE_NOT_FOUND Then
			dwValue = CInt(dwValue)
			If dwValue = intZone Then
				WriteLog " " & sValueName & "://" & sRegKey 
			End If 
		End If 
	Next
		
	WriteLog ""

End Sub
 
Sub DisplayZoneMapPolicies(sComputer,hHive,sKeyPath,aRegValues,aRegTypes,intZone)

	Dim sRegValue
	Dim sRegKeyPath
	Dim dwValue
	
	For Each sRegValue In aRegValues			
		dwValue = Registry_ReadKey(sComputer,hHive,sKeyPath,sRegValue)
		If dwValue <> VALUE_NOT_FOUND Then
			dwValue = CInt(dwValue)
			If dwValue = intZone Then
				WriteLog " " & sRegValue 
			End If 
		End If 
	Next
		
	WriteLog ""

End Sub
 
'--------------------------------------------------------------------
' Read a value from the registry
'--------------------------------------------------------------------

Function Registry_ReadKey (sComputer, hRootKey, sRegKey, sRegValue)
 	
 	dim oRemote
	Dim aValueNames
	Dim aValueTypes
	Dim sValueName
	Dim sData
	Dim dwData
	Dim bData
	Dim aData
	Dim iNr
	Dim iNr2

	Registry_ReadKey = VALUE_NOT_FOUND

	If  len(sRegValue) = 0 Then
		g_oReg.GetStringValue hRootKey, sRegKey, "", sData
		If Len(sData) > 0 then		
			Registry_ReadKey = sData
		End If 
		Exit Function 
	End If

	g_oReg.EnumValues hRootKey, sRegKey, aValueNames, aValueTypes

	If  TypeName(aValueNames) = "Null" Then
		Exit Function
	End If

	For iNr = LBound(aValueNames) To UBound(aValueNames)
		If UCase(aValueNames(iNr)) = UCase(sRegValue) Then
		    Select Case aValueTypes(iNr)
		        Case REG_SZ
					g_oReg.GetStringValue hRootKey, sRegKey, sRegValue, sData
					Registry_ReadKey = sData
		        Case REG_EXPAND_SZ
					g_oReg.GetExpandedStringValue hRootKey, sRegKey, sRegValue, sData
					Registry_ReadKey = sData
		        Case REG_BINARY
					g_oReg.GetBinaryValue hRootKey, sRegKey, sRegValue, aData
					For iNr2 = LBound(aData) To UBound(aData)
						aData(iNr2) = Hex(aData(iNr2))
						If Len(aData(iNr2)) < 2 Then
							aData(iNr2) = "0" & aData(iNr2)
						End If 
					Next 
					Registry_ReadKey = Join(aData,"")
		        Case REG_DWORD
					g_oReg.GetDWORDValue hRootKey, sRegKey, sRegValue, dwData
					Registry_ReadKey = CStr(dwData)
		        Case REG_MULTI_SZ
					g_oReg.GetMultiStringValue  hRootKey, sRegKey, sRegValue, aData
					Registry_ReadKey = Join(aData,vbCrLf)
		    End Select 
		    Exit Function 
		End If 
	Next
			
End Function			

'--------------------------------------------------------------------
' Enumerate a set of values from the registry
'--------------------------------------------------------------------

Function Registry_EnumValues (sComputer, hRootKey, sRegKey, aRegValueNames, aRegValueTypes)
 	
	Registry_EnumValues = True 

	g_oReg.EnumValues hRootKey, sRegKey, aRegValueNames, aRegValueTypes

	If  TypeName(aRegValueNames) = "Null" Then
		Registry_EnumValues = False 
	End If
		
			
End Function			

'--------------------------------------------------------------------
' Enumerate a set of keys from the registry
'--------------------------------------------------------------------

Function Registry_EnumKeys (sComputer, hRootKey, sRegKey, aRegKeysNames)
 	
	Registry_EnumKeys = True 

	g_oReg.EnumKey hRootKey, sRegKey, aRegKeysNames

	If  TypeName(aRegKeysNames) = "Null" Then
		Registry_EnumKeys = False 
	End If
		
			
End Function			

'--------------------------------------------------------------------
' Convert a Hexadecimal number to an integer
'--------------------------------------------------------------------

Function HexToInt (sHexNumber)

	Dim iNr
	Dim iResult
	Dim sNb
	Dim iNb
	
	iResult = 0
	
	For iNr = 1 To Len(sHexNumber)	
		sNb = Mid(sHexNumber,Len(sHexNumber)+1-iNr,1)
		If sNb >= "A" And sNb <= "F" Then
			iNb = Asc(sNb)-65+10
		Else
			iNb = sNb
		End if
		iResult = iResult+iNb*(16^(iNr-1))
	Next 
	
	HexToInt = iResult
	
End Function

'--------------------------------------------------------------------
' Sort an array of strings in ascending order
'--------------------------------------------------------------------

Sub SortStringArray (aStrings)

	Dim iNr1 
	Dim iNr2
	Dim sString
	
	For iNr1 = LBound(aStrings) To UBound(aStrings)-1
		For iNr2 = iNr1+1 To UBound(aStrings)
			If aStrings(iNr1) > aStrings(iNr2) Then
				sString = aStrings(iNr1)
				aStrings(iNr1) = aStrings(iNr2)
				aStrings(iNr2) = sString 
			End If 
		Next 
	Next
	 
End Sub 